import * as react_jsx_runtime from 'react/jsx-runtime';

type RedisCredentials = {
    url?: string;
    token?: string;
};

/**
 * Persistence storage interface for the Databrowser.
 */
type RedisBrowserStorage = {
    set: (value: string) => void;
    get: () => string | null;
};
declare const RedisBrowser: ({ token, url, hideTabs, storage, }: RedisCredentials & {
    hideTabs?: boolean;
    /**
     * Persistence storage for the Databrowser.
     *
     * @example
     * ```tsx
     * <RedisBrowser storage={{
     *   set: (value: string) => localStorage.setItem("redis-browser-data", value),
     *   get: () => localStorage.getItem("redis-browser-data") || "",
     * }} />
     * ```
     */
    storage?: RedisBrowserStorage;
}) => react_jsx_runtime.JSX.Element;

export { RedisBrowser, type RedisBrowserStorage };
